#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "callback_proc.h"
#include <libdc1394/dc1394_control.h>
#include <libraw1394/raw1394.h>
#include "video1394.h"

extern GtkWidget *commander_window;
extern GtkWidget *porthole_window;
extern GtkWidget *color_window;
extern GtkWidget *status_window;
extern GtkWidget *aperture_window;
extern GtkWidget *configure_window;
extern GtkWidget *capture_window;
extern GtkWidget *temperature_window;
extern dc1394_camerainfo camera;
extern dc1394_feature_set feature_set;
extern char* feature_op_list[NUM_FEATURES];
extern char* feature_list[NUM_FEATURES];
extern char* feature_frame_list[NUM_FEATURES];
extern char* feature_scale_list[NUM_FEATURES];
extern char* feature_man_list[NUM_FEATURES];
extern char* feature_auto_list[NUM_FEATURES];
extern char* feature_power_list[NUM_FEATURES];

void OpRangeProcedure(GtkButton* widget, int feature)
{
  int err, timeout;
  dc1394bool_t value=TRUE;
  timeout=LOOP_RETRIES;
  err=dc1394_start_one_push_operation(camera.handle, camera.id, feature);
  gtk_widget_set_sensitive(GTK_WIDGET (widget), FALSE);
  while ( value & (timeout>0) )
    {
      usleep(LOOP_SLEEP);
      err=dc1394_is_one_push_in_operation(camera.handle, camera.id, feature, &value);
      // the next line is not working: only the last update occurs
      UpdateRangeValue(GTK_WIDGET (widget),feature);
      timeout--;
    }
  if (timeout==0)
    printf("OP function timed-out!\n");
  gtk_widget_set_sensitive(GTK_WIDGET (widget),TRUE);

}

void ManRangeProcedure(GtkToggleButton *widget, int feature)
{
  int err;
  // sensitive OP function if available
  gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), feature_op_list[feature])),
			   feature_set.feature[feature].one_push);

  switch (feature)
    {
      case FEATURE_WHITE_BALANCE:
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), "whitebal_RV_scale")),TRUE);
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), "whitebal_BU_scale")),TRUE);break;
      case FEATURE_TEMPERATURE:
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), "temp_goal_scale")),TRUE);break;
	// only the goal range is active, the other one is just an indicator
      default:
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), feature_scale_list[feature])),TRUE);
    }
  err=dc1394_auto_on_off(camera.handle, camera.id, feature, FALSE);
  feature_set.feature[feature].auto_active=FALSE;

}

void AutoRangeProcedure(GtkToggleButton *widget, int feature)
{
  int err;

  // unsensitive OP and range function:
  gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), feature_op_list[feature])),FALSE);
  switch(feature)
    {
      case FEATURE_WHITE_BALANCE:
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), "whitebal_RV_scale")),FALSE);
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), "whitebal_BU_scale")),FALSE);break;
      case FEATURE_TEMPERATURE:
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), "temp_goal_scale")),FALSE);break;
      default:
	gtk_widget_set_sensitive(GTK_WIDGET (lookup_widget(GTK_WIDGET (widget), feature_scale_list[feature])),FALSE);
    }
  err=dc1394_auto_on_off(camera.handle, camera.id, feature, TRUE);
  feature_set.feature[feature].auto_active=TRUE;

}

void PowerRangeProcedure(GtkToggleButton* widget, int feature)
{
  int err;
  err=dc1394_feature_on_off(camera.handle, camera.id, feature, widget->active);
  feature_set.feature[feature].is_on=widget->active;

  if (feature==FEATURE_EXPOSURE)
    { // auto exposure disables gain, iris and shutter. 
      gtk_widget_set_sensitive(lookup_widget(GTK_WIDGET (widget),"gain_frame"),!widget->active);
      gtk_widget_set_sensitive(lookup_widget(GTK_WIDGET (widget),"shutter_frame"),!widget->active);
      gtk_widget_set_sensitive(lookup_widget(GTK_WIDGET (widget),"iris_frame"),!widget->active);
      gtk_widget_set_sensitive(lookup_widget(GTK_WIDGET (widget),"exposure_scale"),widget->active);
    }

}
