#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "connect_signals.h"
#include <libdc1394/dc1394_control.h>
#include <libraw1394/raw1394.h>
#include "video1394.h"

extern GtkWidget *commander_window;
extern GtkWidget *porthole_window;
extern GtkWidget *color_window;
extern GtkWidget *status_window;
extern GtkWidget *aperture_window;
extern GtkWidget *configure_window;
extern GtkWidget *capture_window;
extern GtkWidget *temperature_window;
extern dc1394_camerainfo camera;
extern dc1394_feature_set feature_set;
extern char* feature_op_list[NUM_FEATURES];
extern char* feature_list[NUM_FEATURES];
extern char* feature_frame_list[NUM_FEATURES];
extern char* feature_scale_list[NUM_FEATURES];
extern char* feature_man_list[NUM_FEATURES];
extern char* feature_auto_list[NUM_FEATURES];
extern char* feature_power_list[NUM_FEATURES];



void
ConnectRangeSignals()
{
  GtkAdjustment* adj;

  // porthole window:
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(porthole_window,"zoom_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_ZOOM);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(porthole_window,"pan_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_PAN);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(porthole_window,"tilt_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_TILT);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(porthole_window,"focus_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_FOCUS);

  // color window:
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(color_window,"brightness_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_BRIGHTNESS);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(color_window,"gamma_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_GAMMA);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(color_window,"saturation_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_SATURATION);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(color_window,"hue_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_HUE);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(color_window,"sharpness_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_SHARPNESS);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(color_window,"whitebal_BU_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_WHITE_BALANCE+BU);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(color_window,"whitebal_RV_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_WHITE_BALANCE+RV);


  // aperture_window:
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(aperture_window,"exposure_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_EXPOSURE);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(aperture_window,"iris_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_IRIS);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(aperture_window,"shutter_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_SHUTTER);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(aperture_window,"gain_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_GAIN);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(aperture_window,"filter_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_OPTICAL_FILTER);

  // capture window:
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(capture_window,"capqual_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_CAPTURE_QUALITY);
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(capture_window,"capsize_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_CAPTURE_SIZE);

  // temperature window:
  adj=gtk_range_get_adjustment( (GtkRange*) lookup_widget(temperature_window,"temp_goal_scale"));
  gtk_signal_connect (GTK_OBJECT (adj), "value_changed", GTK_SIGNAL_FUNC (on_scale_value_changed), FEATURE_TEMPERATURE);

}

void
on_scale_value_changed             ( GtkAdjustment    *adj,
				     gpointer         user_data)
{
  int err, bu, rv;

  switch((int)user_data)
    {
      case FEATURE_TEMPERATURE:
	err=dc1394_set_temperature(camera.handle,camera.id,adj->value);
	feature_set.feature[FEATURE_TEMPERATURE].target_value=adj->value; break;
      case FEATURE_WHITE_BALANCE+BU:
	err=dc1394_get_white_balance(camera.handle,camera.id,&bu, &rv);
	err=dc1394_set_white_balance(camera.handle,camera.id,adj->value, rv);
	feature_set.feature[FEATURE_WHITE_BALANCE].BU_value=adj->value; break;
      case FEATURE_WHITE_BALANCE+RV:
	err=dc1394_get_white_balance(camera.handle,camera.id,&bu, &rv);
	err=dc1394_set_white_balance(camera.handle,camera.id,bu, adj->value);
	feature_set.feature[FEATURE_WHITE_BALANCE].RV_value=adj->value; break;
      default:
	err=dc1394_set_feature_value(camera.handle,camera.id,(int)user_data,adj->value);
	feature_set.feature[(int)user_data].value=adj->value;
    }
}
