/*
 * Initial main.c file generated by Glade. Edit as required.
 * Glade will not overwrite this file.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "interface.h"
#include "support.h"
#include "update.h"
#include "activate.h"
#include "definitions.h"
#include <libdc1394/dc1394_control.h>
#include <libraw1394/raw1394.h>
#include "video1394.h"

GtkWidget *commander_window;
GtkWidget *porthole_window;
GtkWidget *color_window;
GtkWidget *status_window;
GtkWidget *aperture_window;
GtkWidget *file_selector_window;
GtkWidget *configure_window;
GtkWidget *about_window;
GtkWidget *capture_window;
GtkWidget *temperature_window;
dc1394_camerainfo camera;
int current_memory_channel;
int max_memory_channel;
dc1394_feature_set feature_set;

int
main (int argc, char *argv[])
{
  int camera_num;
  int err;
  nodeid_t *camera_nodes; 
  raw1394handle_t handle;
  
  int port=0; // port 0 is the first IEEE1394 card

#ifdef ENABLE_NLS
  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
  textdomain (PACKAGE);
#endif

  gnome_init ("commander", VERSION, argc, argv);

  // probe the IEEE1394 bus and get the first camera node:
  handle=dc1394_create_handle(port);
  if (handle==0)
    {
      printf("Could not get a handle. Exiting...\n");
      exit(0);
    }

  camera_nodes=dc1394_get_camera_nodes(handle, &camera_num, 0); // 0 not to show the cams.

  if (camera_num<1)
    {
      printf("No camera found. Exiting...\n");
      exit(0);
    }
  err=dc1394_get_camera_info(handle, camera_nodes[0], &camera);
  err=dc1394_init_camera(handle, camera_nodes[0]);

  // Create the permanent control windows.
  // (note BTW that other windows like 'file_selector' are created
  //  and destroyed on purpose while the following windows always exist.)
  commander_window = create_commander_window ();
  porthole_window = create_porthole_window ();
  color_window = create_color_window ();
  aperture_window = create_aperture_window ();
  status_window = create_status_window ();
  capture_window = create_capture_window ();
  temperature_window = create_temp_window ();

  gtk_widget_show (commander_window); // this is the only window shown at boot-time

  // grab the camera basic infos:
  // TODO...

  // grab the camera feature_set info:
  err=dc1394_get_camera_feature_set(camera.handle, camera.id, &feature_set); 

  // Setup the GUI in accordance with the camera capabilities
  ActivateCapabilities();

  // Connect range signals since Glade 0.5 doesn't handle that (can you imagine this??)
  ConnectRangeSignals();

  gtk_main ();

  // should destroy the handle here...

  return 0;
}
